@@ -8,7 +8,7 @@ Weather::GHCN::App::Fetch - Fetch station and weather data from the NOAA GHCN re
 
 =head1 VERSION
 
-version v0.0.005
+version v0.0.006
 
 =head1 SYNOPSIS
 
@@ -52,7 +52,7 @@ use v5.18;  # minimum for Object::Pad
 
 package Weather::GHCN::App::Fetch;
 
-our $VERSION = 'v0.0.005';
+our $VERSION = 'v0.0.006';
 
 use feature 'signatures';
 no warnings 'experimental::signatures';
@@ -94,6 +94,7 @@ use Const::Fast;
 use English         qw( -no_match_vars );
 
 # cpan modules
+use FindBin         qw($Bin);
 use LWP::Simple;
 use Path::Tiny;
 use Text::Abbrev;
@@ -205,12 +206,14 @@ sub run ($progname, $argv_aref) {
         die "*E* -outclip not available (needs Win32::Clipboard)\n";
     }
 
+    my $ghcn_fetch_pl = path($Bin, '..', 'bin', 'ghcn_fetch.pl')->absolute->stringify;
+
     if ( $Opt_help ) {
-        pod2usage( { -verbose => 2, -exitval => 'NOEXIT', -input => 'ghcn_fetch.pl' } );
+        pod2usage( { -verbose => 2, -exitval => 'NOEXIT', -input => $ghcn_fetch_pl } );
         return;
     }
     if ( $Opt_usage ) {
-        pod2usage( { -verbose => 1, -exitval => 'NOEXIT', -input => 'ghcn_fetch.pl' } );
+        pod2usage( { -verbose => 1, -exitval => 'NOEXIT', -input => $ghcn_fetch_pl } );
         return;
     }
 
